@@ -15,15 +15,15 @@ from ..utils import (
 )
 from ..exceptions import *
 
-
 pcfg = PathConfig.parse_obj(get_driver().config.dict())
 gameimage_path = Path(pcfg.arknights_gameimage_path).absolute()
 gamedata_path = Path(pcfg.arknights_gamedata_path).absolute()
-# pcfg = PathConfig()
 
-##### CHARACTER #####
+
+"""CHARACTER"""
 class Character:
     """干员"""
+
     def __init__(self, id_: str = None, data: dict = None):
         self._id = id_
         self._data = data
@@ -169,7 +169,7 @@ class Character:
         """特性，纯文字"""
         desc = self.description
         if "<" in desc and ">" in desc:
-            desc = re.split(r"<[@|$|/].*?>", desc)
+            desc = re.split(r"<[@$/].*?>", desc)
             desc = "".join(desc)
         if self.trait:
             desc = self.trait[0].override_description_plain or desc
@@ -470,6 +470,7 @@ class Character:
 
 class Attributes:
     """面板"""
+
     def __init__(self, cht: Character = None, data: Dict[str, Any] = None):
         self._data = data
         self._character = cht
@@ -607,6 +608,7 @@ class Attributes:
 
 class CharacterTrait:
     """特性，如领主远程降攻为80%"""
+
     def __init__(self, cht: Character, data):
         self._character = cht
         self._data = data
@@ -664,13 +666,14 @@ class CharacterTrait:
         """可读"""
         desc = self._override_description_blackboard
         if "<" in desc and ">" in desc:
-            desc = re.split(r"<[@|$|/].*?>", desc)
+            desc = re.split(r"<[@$/].*?>", desc)
             desc = "".join(desc)
         return desc
 
 
 class CharacterPhase:
     """精英化阶段"""
+
     def __init__(self, cht: Character = None, data: Dict[str, Any] = None, *, level: int = -1):
         self._character = cht
         self._data = data
@@ -708,7 +711,9 @@ class CharacterPhase:
     async def get_elite_cost(self) -> List["Item"]:
         """升级到这一阶段需要材料"""
         cash = [
-            await Item().init(id_="4001", count=(await ConstanceModel.first()).__dict__["evolveGoldCost"][(await self.get_character()).rarity][self.level-1])  # 龙门币
+            await Item().init(id_="4001", count=
+            (await ConstanceModel.first()).__dict__["evolveGoldCost"][(await self.get_character()).rarity][
+                self.level - 1])  # 龙门币
         ]
         if not self._data["evolveCost"]:
             return cash
@@ -733,12 +738,13 @@ class CharacterPhase:
 
 class CharacterTalent:
     """天赋"""
+
     def __init__(self, cht: Character, data: Dict[str, Any]):
         self._character = cht
         self._data = data
 
     def __str__(self):
-        return f"{self.cht} - {self.name}"
+        return f"{self.character} - {self.name}"
 
     @property
     def character(self) -> Character:
@@ -775,7 +781,7 @@ class CharacterTalent:
         """可读"""
         desc = self.description
         if "<" in desc and ">" in desc:
-            desc = re.split(r"<[@|$|/].*?>", desc)
+            desc = re.split(r"<[@$/].*?>", desc)
             desc = "".join(desc)
         return desc
 
@@ -792,6 +798,7 @@ class CharacterTalent:
 
 class CharacterPotentialRank:
     """潜能"""
+
     def __init__(self, cht: Character, data: Dict[str, Any]):
         self._character = cht
         self._data = data
@@ -824,6 +831,7 @@ class CharacterPotentialRank:
 
 class CharacterFavorKeyFrame:
     """好感度"""
+
     def __init__(self, cht: Character, data: Dict[str, Any], level: int = -1):
         self._character = cht
         self._data = data
@@ -847,6 +855,7 @@ class CharacterFavorKeyFrame:
 
 class CharacterAllSkill:
     """所有技能升级(0~7)"""
+
     def __init__(self, cht: Character, data: Dict[str, Any]):
         self._character = cht
         self._data = data
@@ -882,9 +891,10 @@ class CharacterAllSkill:
         # ]
 
 
-##### HANDBOOK #####
+"""HANDBOOK"""
 class HandbookInfo:
     """档案"""
+
     def __init__(self, id_: str = None, data: Dict[str, Any] = None):
         self._id = id_
         self._data = data
@@ -928,6 +938,7 @@ class HandbookInfo:
 
 class HandbookInfoStoryTextAudio:
     """基本档案数据等"""
+
     def __init__(self, handbook_info: HandbookInfo, data_basic: Dict, data_physic: Dict):
         self._handbook_info = handbook_info
         self._data_basic = data_basic
@@ -938,10 +949,9 @@ class HandbookInfoStoryTextAudio:
         """哪个档案的"""
         return self._handbook_info
 
-    @property
-    def symbol(self) -> str:
+    async def get_symbol(self) -> str:
         """代号，即 character.name"""
-        return self.handbook_info.character.name
+        return (await self.handbook_info.get_character()).name
 
     @property
     def sex(self) -> str:
@@ -974,16 +984,19 @@ class HandbookInfoStoryTextAudio:
         return re.findall(r"【[身高|高度]*】(.*?)\n", self._data_basic["storyText"])[0].strip()
 
 
-##### SKILL #####
+"""SKILL"""
 class Skill:
     """干员技能"""
-    def __init__(self, id_: str = None, cht: Character = None, data: Dict[str, Any] = None, extra_data: Dict[str, Any] = None):
+
+    def __init__(self, id_: str = None, cht: Character = None, data: Dict[str, Any] = None,
+                 extra_data: Dict[str, Any] = None):
         self._id = id_
         self._character = cht
         self._data = data
         self._extra_data = extra_data  # 干员的 "skills" 中的内容
 
-    async def init(self, id_: str, cht: Character = None, data: Dict[str, Any] = None, extra_data: Dict[str, Any] = None) -> "Skill":
+    async def init(self, id_: str, cht: Character = None, data: Dict[str, Any] = None,
+                   extra_data: Dict[str, Any] = None) -> "Skill":
         """异步实例化"""
         self._id = id_
         self._character = cht
@@ -1021,7 +1034,7 @@ class Skill:
     def levels(self) -> List["SkillLevel"]:
         """七个等级的技能"""
         return [
-            SkillLevel(skill=self, data=d, level=idx+1)
+            SkillLevel(skill=self, data=d, level=idx + 1)
             for idx, d in enumerate(self._data["levels"])
         ]
 
@@ -1090,6 +1103,7 @@ class Skill:
 
 class SkillLevelUpCondition:
     """技能专精"""
+
     def __init__(self, skill: Skill, data: Dict):
         self._skill = skill
         self._data = data
@@ -1131,6 +1145,7 @@ class SkillLevelUpCondition:
 
 class SkillLevel:
     """技能等级"""
+
     def __init__(self, skill: Skill, data: Dict, level: int):
         self._skill = skill
         self._data = data
@@ -1186,7 +1201,7 @@ class SkillLevel:
         """可读"""
         desc = self._description_blackboard
         if "<" in desc and ">" in desc:
-            desc = re.split(r"<[@|$|/].*?>", desc)
+            desc = re.split(r"<[@$/].*?>", desc)
             desc = "".join(desc)
         return desc
 
@@ -1217,6 +1232,7 @@ class SkillLevel:
 
 class SkillLevelSpData:
     """技能相关数据"""
+
     def __init__(self, data: Dict[str, Any]):
         self._data = data
 
@@ -1268,9 +1284,10 @@ class UnlockCondition:
         return self._data.get("favor", 0)
 
 
-##### ITEM #####
+"""ITEM"""
 class Item:
     """物品"""
+
     def __init__(self, id_: str = None, data: Dict[str, Any] = None, *, count: int = 0, weight: float = 100):
         self._id = id_
         self._count = count  # 有数量需求时填
@@ -1341,7 +1358,7 @@ class Item:
         """可读"""
         desc = self.description
         if "<" in desc and ">" in desc:
-            desc = re.split(r"<[@|$|/].*?>", desc)
+            desc = re.split(r"<[@$/].*?>", desc)
             desc = "".join(desc)
         return desc
 
@@ -1400,7 +1417,7 @@ class Item:
         #     await WorkshopFormula().init(id_=_["formulaId"])
         #     for _ in self._data["buildingProductList"]
         # ] if self._data["buildingProductList"] else []
-    
+
     # 不在 arknights_item_table 中的：
     @property
     def icon(self) -> Image:
@@ -1408,9 +1425,10 @@ class Item:
         return Image.open(gameimage_path / "item" / f"{self.icon_id or self.id}.png")
 
 
-##### WORKSHOP_FORMULA #####
+"""WORKSHOP_FORMULA"""
 class WorkshopFormula:
     """制造站配方"""
+
     def __init__(self, id_: str = None, data: Dict[str, Any] = None):
         self._id = id_
         self._data = data
@@ -1526,9 +1544,10 @@ class WorkshopFormula:
         return
 
 
-##### EQUIP #####
+"""EQUIP"""
 class Equip:
     """模组"""
+
     def __init__(self, id_: str = None, data: Dict = None):
         self._id = id_
         self._data = data
@@ -1582,7 +1601,7 @@ class Equip:
     @property
     def type_name(self) -> str:
         """类型名"""
-        return f"{self._data['typeName1']}{'-' + self._data['typeName2'] if self._data['typeName2']!='None' else ''}"
+        return f"{self._data['typeName1']}{'-' + self._data['typeName2'] if self._data['typeName2'] != 'None' else ''}"
 
     @property
     def unlock_condition(self) -> "UnlockCondition":
@@ -1628,7 +1647,7 @@ class Equip:
         return Image.open(gameimage_path / "equip" / "stage" / f"img_stg{lvl}.png")
 
 
-##### GACHA_POOL #####
+"""GACHA_POOL"""
 class GachaPool:
     def __init__(self, id_: str = None, data: Dict = None):
         self._id = id_
@@ -1651,6 +1670,64 @@ class GachaPool:
     def __repr__(self):
         return self.__str__()
 
+    @staticmethod
+    async def parse_name(name: str) -> Optional["GachaPool"]:
+        """根据名称查"""
+        data = await GachaPoolModel.filter(gachaPoolName=name).first()
+        if not data:
+            raise NamedPoolNotExistException(details=name)
+        return await GachaPool().init(id_=data.gachaPoolId, data=data.__dict__) if data else None
+
+    @staticmethod
+    async def random(
+            named: bool = True,
+            rule: str = None
+    ) -> Optional["GachaPool"]:
+        """
+        随机返回池子
+        :param named: 有池子专属名字
+        :param rule: 池子类型：ATTAIN, NORMAL, LIMITED, LINKAGE
+        :return:
+        """
+        flags_ex = {}
+        flags = {}
+        if named:
+            flags_ex["gachaPoolName"] = "适合多种场合的强力干员"
+        if rule:
+            flags["gachaRuleType"] = rule if rule in {"ATTAIN", "NORMAL", "LIMITED", "LINKAGE"} else "NORMAL"
+
+        data = await GachaPoolModel.exclude(**flags_ex).filter(**flags).annotate(order=Random()).order_by("order")
+        if not data:
+            return None
+        return await GachaPool().init(id_=data[0].gachaPoolId, data=data[0].__dict__) if data else None
+
+    @staticmethod
+    async def all(
+            named: bool = True,
+            rule: str = None
+    ) -> List["GachaPool"]:
+        """
+        返回所有池子
+        :param named: 有池子专属名字
+        :param rule: 池子类型：ATTAIN, NORMAL, LIMITED, LINKAGE
+        :return:
+        """
+        flags_ex = {}
+        flags = {}
+        if named:
+            flags_ex["gachaPoolName"] = "适合多种场合的强力干员"
+        if rule:
+            flags["gachaRuleType"] = rule if rule in {"ATTAIN", "NORMAL", "LIMITED", "LINKAGE"} else "NORMAL"
+        data = await GachaPoolModel.exclude(**flags_ex).filter(**flags).all()
+        if not data:
+            return []
+
+        result = []
+        for d in data:
+            cht = await GachaPool().init(id_=d.gachaPoolId, data=d.__dict__)
+            result.append(cht)
+        return result
+
     @property
     def id(self) -> str:
         """代码名"""
@@ -1692,9 +1769,10 @@ class GachaPool:
         return self._data["gachaRuleType"]
 
 
-##### SKIN #####
+"""SKIN"""
 class Skin:
     """皮肤"""
+
     def __init__(self, id_: str = None, data: dict = None):
         self._id = id_
         self._data = data
@@ -1774,6 +1852,7 @@ class Skin:
 
 class SkinDisplaySkin:
     """显示信息"""
+
     def __init__(self, skin: "Skin", data):
         self._skin = skin
         self._data = data
@@ -1834,6 +1913,12 @@ class SkinDisplaySkin:
         return self._data["getTime"]
 
 
+"""TODO"""
+class Stage: ...
+class Room: ...
+class Mission: ...
+
+
 __all__ = [
     "Character",
     "Skill",
@@ -1841,4 +1926,4 @@ __all__ = [
     "Equip",
     "GachaPool",
     "Skin"
-]
\ No newline at end of file
+]
